function [phis,mu,energy,counter] = groundstate1d(h,d,c,N,theta,NH,beta,exact,potential)
%
% Calling 
%
% [psis,mu,energy] = groundstate1d(theta,NH)
%
% the harmonic potential x^2/2 is used.
%
% Calling
%
% [psis,mu,energy] = groundstate1d(theta,NH,@v,a,b,...)
%
% the potential defined in the function v(x,a,b,...) is used. 
% a,b,... are optional parameters for the potential v(x).
%
tol = 1e-7;
[phis,Hw,ev,diffpotential,contparams] = init1d(N,NH,h,d,c,beta,potential);
phisold = phis;
convergence = 0;
% NHewton
counter(1) = 1;
%continuation technique
params = [1,theta];
contparams = [contparams,min(theta,1/N)];
contparamsold = contparams;
contparamsinc = [0.25 0.25]; % magic numbers
contparamsincmin = [1e-6 1e-6];
conttolerance = tol*1e5; % magic number
maxnewtoniter = 50; % magic number
optnewtoniter = 2;
singtol = []; % magic number used in newton1d
alphainit = 1e-2; % magic number
lambdamin = 1e-5; % magic number  % to be removed afterwards
while (min(contparams >= params) == 0)
  contparams = min(params,contparamsold.*(1+contparamsinc));
  phis = phisold;
  % perform one continuation cycle
  [retcode,errest,phis,newtoniter] = minimize(phis,contparams,alphainit,Hw,ev,diffpotential,@energy1d,@phirw1d,@residual1d,@newton1d,@error1d,exact,singtol,conttolerance,maxnewtoniter,N,NH);
  if (retcode == 1) % newton did not converge
    contparamsinc = contparamsinc/2;		
    warning('Decreasing continuation increments.');
    if (contparamsinc < contparamsincmin)
      error('Minimum value for the parameter increments reached.')
    end
  else % newton converged
    if (newtoniter < optnewtoniter) % if newton converged within optnewtoniter steps increase increment
       contparamsinc = 2*contparamsinc;
    end
    % the new theta is temptheta
    contparamsold = contparams;		
    phisold = phis;
    counter(1) = counter(1)+1;
  end
end
contparams = params;
errest = tol+1;
alphainit = alphainit/100;
optalpha = alphainit;
counter(2) = 0;
maxnewtoniter = 500;
[retcode,errest,phis,newtoniter,energy,mu] = minimize(phis,contparams,alphainit,Hw,ev,diffpotential,@energy1d,@phirw1d,@residual1d,@newton1d,@error1d,exact,singtol,tol,maxnewtoniter,N,NH);
counter(2)=newtoniter;
energy = h*energy;
mu = h*mu;
if (retcode == 1) % not possible to find an acceptable steplength -> stop the iteration
  warning(sprintf('Not possible to further reduce the energy. Current errest: %e',errest));
end
phis = sqrt(sqrt(c))*phis(1:NH);
phirw = phirw1d(NH,phis,Hw);
