function [phis,Hw,ev,diffpotential,contparams] = init1d(N,NH,h,d,c,beta,potential) 
% initial solution, Hermite functions, eigenvalues, diffpotential,
indx = 0;
delta = sqrt(2);
% Gauss--Hermite quadrature nodes and (fourth root of) weights relative to the 
% weight w(x) = exp(-(delta*beta*x)^2).
ab = r_hermite(2*NH-1);
[xw] = gauss(2*NH-1,ab);
x = xw(:,1)/delta/beta;
[dummy,idx] = sort(abs(x),'descend');
x = x(idx);
w = (xw(:,2)/delta/beta).^0.25;
w = w(idx);
% Hermite polynomials orthonormal with respect to the weight w(x/delta),
% times the weights
Hw = hermatw(x,NH,beta,w');
%sum(Hw.^3.*repmat(exp(beta^2*x'.^2/2),NH,1),2) to show that the order of
%nodes is important
% Initial guess: the polynomial part of the ground state for the 
% Schroedinger equation with harmonic potential, times the weights.
% Hw(1,:)' is the ground state
% Hw(2,:)' is the first excited state and so on
%phirw = Hw(index+1,:)'/sqrt(beta).*exp((beta^2-1)*x.^2/2);
phirw = Hw(indx+1,:)';
% Coefficients with respect to the Hermite functions of the initial guess.
% phi(x)*exp(x^2/2) is phir
phis = Hw*(phirw.*(exp((beta*x).^2/2).*w).^2);
phis = sqrt(N)*phis;
% Initial guess for mu = 0.5.
phis(NH+1) = (indx+0.5);
phis = phis(:);
% The difference between the actual potential and the standard
% harmonic one
diffpotential = (feval(potential,x/sqrt(c))/h-d*(beta^2*x).^2/2);
diffpotential = diffpotential.*(exp((beta*x).^2/2).*w).^2;
% Eigenvalues relative to -d^2 / d x^2 + 1/2 (beta^2*x)^2
ev = d*(2*[0:NH-1]'+1)*beta^2;
contparams = 1/(sum(abs(diffpotential).*phirw.^2)+1);
