function [retcode,phis,phirw,penalty,lambda] = linesearch(N,NH,phis,dphis,initslope,penaltyold,alpha,energyfun,phirwfun,contparams,Hw,ev,diffpotential,r)
% calculates a steplength lambda, that satisfies the
% Armijo-Goldstein condition. If not possible, 'retcode'
% is set to 1
% Dennis J. E. and Schnabel R. B., Numerical Methods for unconstrained
% optimization and nonlinear equations, SIAM, 1998
lambdamin = 1e-5; % magic number
lambda = 1;
tempphis = phis+lambda*dphis;
phirw = feval(phirwfun,NH,tempphis,Hw);
[energy,penalty] = feval(energyfun,N,NH,tempphis,phirw,contparams,ev,...
                   diffpotential,r);

while(penalty > penaltyold-alpha*lambda*abs(initslope))
  if(lambda < lambdamin) % lambda too small; stop the linesearch
    retcode = 1;
% try with alphainit    
    return;
  else
    if(lambda == 1) % then first reduction -> quadratic model      
      lambdatemp = -initslope/(2*(penalty-penaltyold-initslope));
    else % lambda < 1 -> cubic model
      a = 1/(lambda-lambdaprev)*...
          [1/lambda^2,-1/(lambdaprev^2);-lambdaprev/lambda^2,...
          lambda/lambdaprev^2]*[penalty-penaltyold-lambda*initslope;...
          penaltyprev-penaltyold-lambdaprev*initslope];
      % discriminat
      disc = a(2)^2-3*a(1)*initslope;
      if (a(1) == 0) % the cubic model is quadratic; lambdatemp is the minimizer of the quadratic model
        lambdatemp = -initslope/(2*a(2));
      else % lambdatemp is the minimizer of the cubic model
        lambdatemp = (-a(2)+sqrt(disc))/(3*a(1));
      end
    end
    penaltyprev = penalty;
    % the decrement of lambda has to be bounded
    lambdaprev = lambda;
    lambda = min(max(lambdatemp,lambda/10),lambda/2);
  end
  % calculate tempphis for apropriate lambda
  tempphis = phis+lambda*dphis;
  phirw = feval(phirwfun,NH,tempphis,Hw);
  [energy,penalty] = feval(energyfun,N,NH,tempphis,phirw,contparams, ...
                           ev,diffpotential,r);
end
if (penaltyold < penalty)
  error('Penalty increasing.');
end
retcode = 0;
phis = tempphis;
