% HERMAT Builds the collocation Hermite matrix.
%   H=HERMAT(X,N) builds the matrix H_i(X(j))), where H_i is the
%   normalized Hermite polynomial of degree i-1, 1<=i<=N,
%   1<=j<=length(X).
%
%   H=HERMAT(X,N,GAMMA) builds the matrix sqrt(GAMMA)*H_i(GAMMA*X(j)).
%
% With WEIGHTS
function [H,H1] = hermatw(x,N,varargin)
if (nargin >= 3)
  gamma = varargin{1};
else
  gamma = 1;
end
if (nargin == 4)
  W = varargin{2};
else
  W = ones(1,length(x));
end
if (nargout == 2)
  N = N+1;
end
x = x(:).';
H = ones(N,length(x))*sqrt(gamma)/sqrt(sqrt(pi));
H(1,:) = H(1,:).*W;
if (N == 1) 
  return
end
sqrti = sqrt(2);
xx = sqrti*gamma*x;
H(2,:) = sqrt(gamma)*xx.*W/sqrt(sqrt(pi));
sqrti1 = 1;
for i = 3:N
% the degree is i-1
  H(i,:) = (xx.*H(i-1,:)-sqrti1*H(i-2,:))/sqrti;
  sqrti1 = sqrti;
  sqrti = sqrt(i);
end
if (nargout == 2)
  N = N-1;
  n = [2:N]';
  H1 = [-sqrt(2)*gamma/2*H(2,:);...
	gamma/2*spdiags(sqrt(2*(n-1)),0,N-1,N-1)*...
	H(n-1,:)-...
	gamma/2*spdiags(sqrt(2*n),0,N-1,N-1)*H(n+1,:)];
end
H = H(1:N,:);